beamprofiler.iso.characterizing\_parameters.clip\_level\_average\_power\_density
================================================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: clip_level_average_power_density